# Prerequisites
_Please answer the following questions for yourself before submitting an issue._
- [ ] I am running the latest version
- [ ] I checked the documentation and found no answer
- [ ] I checked to make sure that this issue has not already been filed
- [ ] I'm reporting the issue to the correct repository (for multi-repository projects)

# Instructions
_Please complete the following sections of the issue template, removing irrelevant components._

---

# Bug Report
_Remove this section if your issue is not a bug. Make sure to add the __Type: Bug__ label if it is._

## Failure Information
_Please help provide information about the failure._

## Bug Report: Expected Behavior
_(Expected behavior that isn't occurring)_

## Bug Report: Current Behavior
_(Description of the current, buggy behavior)_

## Bug Report: Steps to Reproduce
_Please provide detailed steps for reproducing the issue._
1. Step 1
2. Step 2
3. Etc.

## Bug Report: Context
_Please provide any relevant information about your setup. This is important in case the issue is not reproducible except for under certain conditions._
- OS:
- Python version:
- `solaris` install method (Conda, pip, Docker):
- `solaris` version (release vs. dev) - if you're using an older release, please update and ensure your issue isn't resolved:
- Additional relevant environment details (e.g. using a virtual environment or not, version of GDAL and GDAL install method, etc.)

## Bug Report: Failure Logs
_Please include any relevant log snippets, python shell commands and tracebacks, etc. here._

---

# Feature Request
_Remove this section if your issue is not a feature request. Make sure to add the __Type: Enhancement__ label if it is._
## Feature Description
_Please describe the feature you'd like implemented._

## Feature Request: Changes to API
_If your feature request includes changes to the `solaris` API, describe that here. Note that any changes to required arguments or argument order in the API will only be made at a major version release. See [the contributing guidelines]() for additional details._

---

# Final steps

## References to other issues/PRs
_If you did not already include references above, list references to relevant PRs, issues, or other pages here._

## Labels
_Make sure to select a __Type__ label for your issue. The repo maintainers will add other labels, milestones, and projects (if applicable)._
